# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: canvas_generated/messages/effects.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'canvas_generated/messages/effects.proto\x12\x06\x63\x61nvas\"\x98\x01\n\x06\x45\x66\x66\x65\x63t\x12 \n\x04type\x18\x01 \x01(\x0e\x32\x12.canvas.EffectType\x12\x0f\n\x07payload\x18\x02 \x01(\t\x12\x13\n\x0bplugin_name\x18\x03 \x01(\t\x12\x11\n\tclassname\x18\x04 \x01(\t\x12\x14\n\x0chandler_name\x18\x05 \x01(\t\x12\r\n\x05\x61\x63tor\x18\x06 \x01(\t\x12\x0e\n\x06source\x18\x07 \x01(\t*\xd1V\n\nEffectType\x12\x12\n\x0eUNKNOWN_EFFECT\x10\x00\x12\x07\n\x03LOG\x10\x01\x12\x14\n\x10\x41\x44\x44_PLAN_COMMAND\x10\x02\x12\x1f\n\x1b\x41UTOCOMPLETE_SEARCH_RESULTS\x10\x03\x12\x14\n\x10\x41\x44\x44_BANNER_ALERT\x10\x04\x12\x17\n\x13REMOVE_BANNER_ALERT\x10\x05\x12\x1c\n\x18ORIGINATE_ASSESS_COMMAND\x10\x06\x12\x17\n\x13\x45\x44IT_ASSESS_COMMAND\x10\x07\x12\x19\n\x15\x44\x45LETE_ASSESS_COMMAND\x10\x08\x12\x19\n\x15\x43OMMIT_ASSESS_COMMAND\x10\t\x12!\n\x1d\x45NTER_IN_ERROR_ASSESS_COMMAND\x10\n\x12\x1e\n\x1aORIGINATE_DIAGNOSE_COMMAND\x10\x0b\x12\x19\n\x15\x45\x44IT_DIAGNOSE_COMMAND\x10\x0c\x12\x1b\n\x17\x44\x45LETE_DIAGNOSE_COMMAND\x10\r\x12\x1b\n\x17\x43OMMIT_DIAGNOSE_COMMAND\x10\x0e\x12#\n\x1f\x45NTER_IN_ERROR_DIAGNOSE_COMMAND\x10\x0f\x12\x1a\n\x16ORIGINATE_GOAL_COMMAND\x10\x10\x12\x15\n\x11\x45\x44IT_GOAL_COMMAND\x10\x11\x12\x17\n\x13\x44\x45LETE_GOAL_COMMAND\x10\x12\x12\x17\n\x13\x43OMMIT_GOAL_COMMAND\x10\x13\x12\x1f\n\x1b\x45NTER_IN_ERROR_GOAL_COMMAND\x10\x14\x12\x19\n\x15ORIGINATE_HPI_COMMAND\x10\x15\x12\x14\n\x10\x45\x44IT_HPI_COMMAND\x10\x16\x12\x16\n\x12\x44\x45LETE_HPI_COMMAND\x10\x17\x12\x16\n\x12\x43OMMIT_HPI_COMMAND\x10\x18\x12\x1e\n\x1a\x45NTER_IN_ERROR_HPI_COMMAND\x10\x19\x12*\n&ORIGINATE_MEDICATION_STATEMENT_COMMAND\x10\x1a\x12%\n!EDIT_MEDICATION_STATEMENT_COMMAND\x10\x1b\x12\'\n#DELETE_MEDICATION_STATEMENT_COMMAND\x10\x1c\x12\'\n#COMMIT_MEDICATION_STATEMENT_COMMAND\x10\x1d\x12/\n+ENTER_IN_ERROR_MEDICATION_STATEMENT_COMMAND\x10\x1e\x12\x1a\n\x16ORIGINATE_PLAN_COMMAND\x10\x1f\x12\x15\n\x11\x45\x44IT_PLAN_COMMAND\x10 \x12\x17\n\x13\x44\x45LETE_PLAN_COMMAND\x10!\x12\x17\n\x13\x43OMMIT_PLAN_COMMAND\x10\"\x12\x1f\n\x1b\x45NTER_IN_ERROR_PLAN_COMMAND\x10#\x12\x1f\n\x1bORIGINATE_PRESCRIBE_COMMAND\x10$\x12\x1a\n\x16\x45\x44IT_PRESCRIBE_COMMAND\x10%\x12\x1c\n\x18\x44\x45LETE_PRESCRIBE_COMMAND\x10&\x12\x1c\n\x18\x43OMMIT_PRESCRIBE_COMMAND\x10\'\x12$\n ENTER_IN_ERROR_PRESCRIBE_COMMAND\x10(\x12\x1b\n\x16SEND_PRESCRIBE_COMMAND\x10\x99\n\x12\x1d\n\x18REVIEW_PRESCRIBE_COMMAND\x10\x9d\n\x12#\n\x1fORIGINATE_QUESTIONNAIRE_COMMAND\x10)\x12\x1e\n\x1a\x45\x44IT_QUESTIONNAIRE_COMMAND\x10*\x12 \n\x1c\x44\x45LETE_QUESTIONNAIRE_COMMAND\x10+\x12 \n\x1c\x43OMMIT_QUESTIONNAIRE_COMMAND\x10,\x12(\n$ENTER_IN_ERROR_QUESTIONNAIRE_COMMAND\x10-\x12&\n\"ORIGINATE_REASON_FOR_VISIT_COMMAND\x10.\x12!\n\x1d\x45\x44IT_REASON_FOR_VISIT_COMMAND\x10/\x12#\n\x1f\x44\x45LETE_REASON_FOR_VISIT_COMMAND\x10\x30\x12#\n\x1f\x43OMMIT_REASON_FOR_VISIT_COMMAND\x10\x31\x12+\n\'ENTER_IN_ERROR_REASON_FOR_VISIT_COMMAND\x10\x32\x12%\n!ORIGINATE_STOP_MEDICATION_COMMAND\x10\x33\x12 \n\x1c\x45\x44IT_STOP_MEDICATION_COMMAND\x10\x34\x12\"\n\x1e\x44\x45LETE_STOP_MEDICATION_COMMAND\x10\x35\x12\"\n\x1e\x43OMMIT_STOP_MEDICATION_COMMAND\x10\x36\x12*\n&ENTER_IN_ERROR_STOP_MEDICATION_COMMAND\x10\x37\x12!\n\x1dORIGINATE_UPDATE_GOAL_COMMAND\x10\x38\x12\x1c\n\x18\x45\x44IT_UPDATE_GOAL_COMMAND\x10\x39\x12\x1e\n\x1a\x44\x45LETE_UPDATE_GOAL_COMMAND\x10:\x12\x1e\n\x1a\x43OMMIT_UPDATE_GOAL_COMMAND\x10;\x12&\n\"ENTER_IN_ERROR_UPDATE_GOAL_COMMAND\x10<\x12\x1d\n\x19ORIGINATE_PERFORM_COMMAND\x10=\x12\x18\n\x14\x45\x44IT_PERFORM_COMMAND\x10>\x12\x1a\n\x16\x44\x45LETE_PERFORM_COMMAND\x10?\x12\x1a\n\x16\x43OMMIT_PERFORM_COMMAND\x10@\x12\"\n\x1e\x45NTER_IN_ERROR_PERFORM_COMMAND\x10\x41\x12\x1e\n\x1aORIGINATE_INSTRUCT_COMMAND\x10\x42\x12\x19\n\x15\x45\x44IT_INSTRUCT_COMMAND\x10\x43\x12\x1b\n\x17\x44\x45LETE_INSTRUCT_COMMAND\x10\x44\x12\x1b\n\x17\x43OMMIT_INSTRUCT_COMMAND\x10\x45\x12#\n\x1f\x45NTER_IN_ERROR_INSTRUCT_COMMAND\x10\x46\x12\x1f\n\x1bORIGINATE_LAB_ORDER_COMMAND\x10G\x12\x1a\n\x16\x45\x44IT_LAB_ORDER_COMMAND\x10H\x12\x1c\n\x18\x44\x45LETE_LAB_ORDER_COMMAND\x10I\x12\x1c\n\x18\x43OMMIT_LAB_ORDER_COMMAND\x10J\x12$\n ENTER_IN_ERROR_LAB_ORDER_COMMAND\x10K\x12\x1b\n\x16SEND_LAB_ORDER_COMMAND\x10\x9a\n\x12$\n ORIGINATE_FAMILY_HISTORY_COMMAND\x10L\x12\x1f\n\x1b\x45\x44IT_FAMILY_HISTORY_COMMAND\x10M\x12!\n\x1d\x44\x45LETE_FAMILY_HISTORY_COMMAND\x10N\x12!\n\x1d\x43OMMIT_FAMILY_HISTORY_COMMAND\x10O\x12)\n%ENTER_IN_ERROR_FAMILY_HISTORY_COMMAND\x10P\x12\x1d\n\x19ORIGINATE_ALLERGY_COMMAND\x10Q\x12\x18\n\x14\x45\x44IT_ALLERGY_COMMAND\x10R\x12\x1a\n\x16\x44\x45LETE_ALLERGY_COMMAND\x10S\x12\x1a\n\x16\x43OMMIT_ALLERGY_COMMAND\x10T\x12\"\n\x1e\x45NTER_IN_ERROR_ALLERGY_COMMAND\x10U\x12$\n ORIGINATE_REMOVE_ALLERGY_COMMAND\x10V\x12\x1f\n\x1b\x45\x44IT_REMOVE_ALLERGY_COMMAND\x10W\x12!\n\x1d\x44\x45LETE_REMOVE_ALLERGY_COMMAND\x10X\x12!\n\x1d\x43OMMIT_REMOVE_ALLERGY_COMMAND\x10Y\x12)\n%ENTER_IN_ERROR_REMOVE_ALLERGY_COMMAND\x10Z\x12&\n\"ORIGINATE_SURGICAL_HISTORY_COMMAND\x10[\x12!\n\x1d\x45\x44IT_SURGICAL_HISTORY_COMMAND\x10\\\x12#\n\x1f\x44\x45LETE_SURGICAL_HISTORY_COMMAND\x10]\x12#\n\x1f\x43OMMIT_SURGICAL_HISTORY_COMMAND\x10^\x12+\n\'ENTER_IN_ERROR_SURGICAL_HISTORY_COMMAND\x10_\x12\x0f\n\x0b\x43REATE_TASK\x10\x64\x12\x0f\n\x0bUPDATE_TASK\x10\x65\x12\x17\n\x13\x43REATE_TASK_COMMENT\x10\x66\x12\x18\n\x14UPSERT_TASK_METADATA\x10o\x12%\n!ORIGINATE_MEDICAL_HISTORY_COMMAND\x10g\x12 \n\x1c\x45\x44IT_MEDICAL_HISTORY_COMMAND\x10h\x12\"\n\x1e\x44\x45LETE_MEDICAL_HISTORY_COMMAND\x10i\x12\"\n\x1e\x43OMMIT_MEDICAL_HISTORY_COMMAND\x10j\x12*\n&ENTER_IN_ERROR_MEDICAL_HISTORY_COMMAND\x10k\x12\x1f\n\x1b\x41\x44\x44_OR_UPDATE_PROTOCOL_CARD\x10n\x12\x1b\n\x16ORIGINATE_TASK_COMMAND\x10\x85\x01\x12\x16\n\x11\x45\x44IT_TASK_COMMAND\x10\x86\x01\x12\x18\n\x13\x44\x45LETE_TASK_COMMAND\x10\x87\x01\x12\x18\n\x13\x43OMMIT_TASK_COMMAND\x10\x88\x01\x12 \n\x1b\x45NTER_IN_ERROR_TASK_COMMAND\x10\x89\x01\x12\x1c\n\x18ORIGINATE_REFILL_COMMAND\x10q\x12\x17\n\x13\x45\x44IT_REFILL_COMMAND\x10r\x12\x19\n\x15\x44\x45LETE_REFILL_COMMAND\x10s\x12\x19\n\x15\x43OMMIT_REFILL_COMMAND\x10t\x12!\n\x1d\x45NTER_IN_ERROR_REFILL_COMMAND\x10u\x12\x18\n\x13SEND_REFILL_COMMAND\x10\x9c\n\x12\x1a\n\x15REVIEW_REFILL_COMMAND\x10\x9e\n\x12\x1c\n\x18ORIGINATE_VITALS_COMMAND\x10v\x12\x17\n\x13\x45\x44IT_VITALS_COMMAND\x10w\x12\x19\n\x15\x44\x45LETE_VITALS_COMMAND\x10x\x12\x19\n\x15\x43OMMIT_VITALS_COMMAND\x10y\x12!\n\x1d\x45NTER_IN_ERROR_VITALS_COMMAND\x10z\x12&\n\"ORIGINATE_UPDATE_DIAGNOSIS_COMMAND\x10{\x12!\n\x1d\x45\x44IT_UPDATE_DIAGNOSIS_COMMAND\x10|\x12#\n\x1f\x44\x45LETE_UPDATE_DIAGNOSIS_COMMAND\x10}\x12#\n\x1f\x43OMMIT_UPDATE_DIAGNOSIS_COMMAND\x10~\x12+\n\'ENTER_IN_ERROR_UPDATE_DIAGNOSIS_COMMAND\x10\x7f\x12!\n\x1cORIGINATE_CLOSE_GOAL_COMMAND\x10\x80\x01\x12\x1c\n\x17\x45\x44IT_CLOSE_GOAL_COMMAND\x10\x81\x01\x12\x1e\n\x19\x44\x45LETE_CLOSE_GOAL_COMMAND\x10\x82\x01\x12\x1e\n\x19\x43OMMIT_CLOSE_GOAL_COMMAND\x10\x83\x01\x12&\n!ENTER_IN_ERROR_CLOSE_GOAL_COMMAND\x10\x84\x01\x12\x1c\n\x17ORIGINATE_REFER_COMMAND\x10\x8b\x01\x12\x17\n\x12\x45\x44IT_REFER_COMMAND\x10\x8c\x01\x12\x19\n\x14\x44\x45LETE_REFER_COMMAND\x10\x8d\x01\x12\x19\n\x14\x43OMMIT_REFER_COMMAND\x10\x8e\x01\x12!\n\x1c\x45NTER_IN_ERROR_REFER_COMMAND\x10\x8f\x01\x12(\n#ORIGINATE_CHANGE_MEDICATION_COMMAND\x10\x96\x01\x12#\n\x1e\x45\x44IT_CHANGE_MEDICATION_COMMAND\x10\x97\x01\x12%\n DELETE_CHANGE_MEDICATION_COMMAND\x10\x98\x01\x12%\n COMMIT_CHANGE_MEDICATION_COMMAND\x10\x99\x01\x12-\n(ENTER_IN_ERROR_CHANGE_MEDICATION_COMMAND\x10\x9a\x01\x12 \n\x1b\x43REATE_QUESTIONNAIRE_RESULT\x10\x8a\x01\x12-\n(ANNOTATE_PATIENT_CHART_CONDITION_RESULTS\x10\xc8\x01\x12\x32\n-ANNOTATE_PATIENT_CHART_DETECTED_ISSUE_RESULTS\x10\xc9\x01\x12%\n ANNOTATE_CLAIM_CONDITION_RESULTS\x10\xac\x02\x12(\n#SHOW_PATIENT_CHART_SUMMARY_SECTIONS\x10\x90\x03\x12\"\n\x1dSHOW_PATIENT_PROFILE_SECTIONS\x10\xf4\x03\x12\x37\n2PATIENT_PROFILE__ADD_PHARMACY__POST_SEARCH_RESULTS\x10\xf5\x03\x12)\n$SEND_SURESCRIPTS_ELIGIBILITY_REQUEST\x10\xd8\x04\x12\x30\n+SEND_SURESCRIPTS_MEDICATION_HISTORY_REQUEST\x10\xd9\x04\x12&\n!SEND_SURESCRIPTS_BENEFITS_REQUEST\x10\xda\x04\x12\x1b\n\x16ORIGINATE_EXAM_COMMAND\x10\xbc\x05\x12\x16\n\x11\x45\x44IT_EXAM_COMMAND\x10\xbd\x05\x12\x18\n\x13\x44\x45LETE_EXAM_COMMAND\x10\xbe\x05\x12\x18\n\x13\x43OMMIT_EXAM_COMMAND\x10\xbf\x05\x12 \n\x1b\x45NTER_IN_ERROR_EXAM_COMMAND\x10\xc0\x05\x12\x1a\n\x15ORIGINATE_ROS_COMMAND\x10\xa0\x06\x12\x15\n\x10\x45\x44IT_ROS_COMMAND\x10\xa1\x06\x12\x17\n\x12\x44\x45LETE_ROS_COMMAND\x10\xa2\x06\x12\x17\n\x12\x43OMMIT_ROS_COMMAND\x10\xa3\x06\x12\x1f\n\x1a\x45NTER_IN_ERROR_ROS_COMMAND\x10\xa4\x06\x12,\n\'ORIGINATE_STRUCTURED_ASSESSMENT_COMMAND\x10\x84\x07\x12\'\n\"EDIT_STRUCTURED_ASSESSMENT_COMMAND\x10\x85\x07\x12)\n$DELETE_STRUCTURED_ASSESSMENT_COMMAND\x10\x86\x07\x12)\n$COMMIT_STRUCTURED_ASSESSMENT_COMMAND\x10\x87\x07\x12\x31\n,ENTER_IN_ERROR_STRUCTURED_ASSESSMENT_COMMAND\x10\x88\x07\x12 \n\x1bORIGINATE_FOLLOW_UP_COMMAND\x10\x89\x07\x12\x1b\n\x16\x45\x44IT_FOLLOW_UP_COMMAND\x10\x8a\x07\x12\x1d\n\x18\x44\x45LETE_FOLLOW_UP_COMMAND\x10\x8b\x07\x12\x1d\n\x18\x43OMMIT_FOLLOW_UP_COMMAND\x10\x8c\x07\x12%\n ENTER_IN_ERROR_FOLLOW_UP_COMMAND\x10\x8d\x07\x12$\n\x1fORIGINATE_IMAGING_ORDER_COMMAND\x10\xcc\x08\x12\x1f\n\x1a\x45\x44IT_IMAGING_ORDER_COMMAND\x10\xcd\x08\x12!\n\x1c\x44\x45LETE_IMAGING_ORDER_COMMAND\x10\xce\x08\x12!\n\x1c\x43OMMIT_IMAGING_ORDER_COMMAND\x10\xcf\x08\x12)\n$ENTER_IN_ERROR_IMAGING_ORDER_COMMAND\x10\xd0\x08\x12(\n#ORIGINATE_RESOLVE_CONDITION_COMMAND\x10\xb0\t\x12#\n\x1e\x45\x44IT_RESOLVE_CONDITION_COMMAND\x10\xb1\t\x12%\n DELETE_RESOLVE_CONDITION_COMMAND\x10\xb2\t\x12%\n COMMIT_RESOLVE_CONDITION_COMMAND\x10\xb3\t\x12-\n(ENTER_IN_ERROR_RESOLVE_CONDITION_COMMAND\x10\xb4\t\x12*\n%ORIGINATE_ADJUST_PRESCRIPTION_COMMAND\x10\x94\n\x12%\n EDIT_ADJUST_PRESCRIPTION_COMMAND\x10\x95\n\x12\'\n\"DELETE_ADJUST_PRESCRIPTION_COMMAND\x10\x96\n\x12\'\n\"COMMIT_ADJUST_PRESCRIPTION_COMMAND\x10\x97\n\x12/\n*ENTER_IN_ERROR_ADJUST_PRESCRIPTION_COMMAND\x10\x98\n\x12%\n SEND_ADJUST_PRESCRIPTION_COMMAND\x10\x9b\n\x12\'\n\"REVIEW_ADJUST_PRESCRIPTION_COMMAND\x10\x9f\n\x12+\n&ORIGINATE_CHART_SECTION_REVIEW_COMMAND\x10\xf8\n\x12-\n(ORIGINATE_IMMUNIZATION_STATEMENT_COMMAND\x10\xdc\x0b\x12(\n#EDIT_IMMUNIZATION_STATEMENT_COMMAND\x10\xdd\x0b\x12*\n%DELETE_IMMUNIZATION_STATEMENT_COMMAND\x10\xde\x0b\x12*\n%COMMIT_IMMUNIZATION_STATEMENT_COMMAND\x10\xdf\x0b\x12\x32\n-ENTER_IN_ERROR_IMMUNIZATION_STATEMENT_COMMAND\x10\xe0\x0b\x12!\n\x1cORIGINATE_LAB_REVIEW_COMMAND\x10\xe1\x0b\x12\x1c\n\x17\x45\x44IT_LAB_REVIEW_COMMAND\x10\xe2\x0b\x12\x1e\n\x19\x44\x45LETE_LAB_REVIEW_COMMAND\x10\xe3\x0b\x12\x1e\n\x19\x43OMMIT_LAB_REVIEW_COMMAND\x10\xe4\x0b\x12&\n!ENTER_IN_ERROR_LAB_REVIEW_COMMAND\x10\xe5\x0b\x12%\n ORIGINATE_IMAGING_REVIEW_COMMAND\x10\xe6\x0b\x12 \n\x1b\x45\x44IT_IMAGING_REVIEW_COMMAND\x10\xe7\x0b\x12\"\n\x1d\x44\x45LETE_IMAGING_REVIEW_COMMAND\x10\xe8\x0b\x12\"\n\x1d\x43OMMIT_IMAGING_REVIEW_COMMAND\x10\xe9\x0b\x12*\n%ENTER_IN_ERROR_IMAGING_REVIEW_COMMAND\x10\xea\x0b\x12&\n!ORIGINATE_REFERRAL_REVIEW_COMMAND\x10\xeb\x0b\x12!\n\x1c\x45\x44IT_REFERRAL_REVIEW_COMMAND\x10\xec\x0b\x12#\n\x1e\x44\x45LETE_REFERRAL_REVIEW_COMMAND\x10\xed\x0b\x12#\n\x1e\x43OMMIT_REFERRAL_REVIEW_COMMAND\x10\xee\x0b\x12+\n&ENTER_IN_ERROR_REFERRAL_REVIEW_COMMAND\x10\xef\x0b\x12\x34\n/ORIGINATE_UNCATEGORIZED_DOCUMENT_REVIEW_COMMAND\x10\xf0\x0b\x12/\n*EDIT_UNCATEGORIZED_DOCUMENT_REVIEW_COMMAND\x10\xf1\x0b\x12\x31\n,DELETE_UNCATEGORIZED_DOCUMENT_REVIEW_COMMAND\x10\xf2\x0b\x12\x31\n,COMMIT_UNCATEGORIZED_DOCUMENT_REVIEW_COMMAND\x10\xf3\x0b\x12\x39\n4ENTER_IN_ERROR_UNCATEGORIZED_DOCUMENT_REVIEW_COMMAND\x10\xf4\x0b\x12&\n!COMMAND_AVAILABLE_ACTIONS_RESULTS\x10\xc0\x0c\x12\x1e\n\x19\x43OMMAND_VALIDATION_ERRORS\x10\xc1\x0c\x12\x17\n\x12SHOW_ACTION_BUTTON\x10\xe8\x07\x12 \n\x1bPATIENT_PORTAL__FORM_RESULT\x10\xd0\x0f\x12.\n)PATIENT_PORTAL__APPOINTMENT_IS_CANCELABLE\x10\xd1\x0f\x12\x31\n,PATIENT_PORTAL__APPOINTMENT_IS_RESCHEDULABLE\x10\xd2\x0f\x12\x32\n-PATIENT_PORTAL__APPOINTMENT_SHOW_MEETING_LINK\x10\xd3\x0f\x12 \n\x1bPATIENT_PORTAL__SEND_INVITE\x10\xd4\x0f\x12.\n)PATIENT_PORTAL__SEND_CONTACT_VERIFICATION\x10\xdd\x0f\x12=\n8PATIENT_PORTAL__APPOINTMENTS__SLOTS__POST_SEARCH_RESULTS\x10\xd5\x0f\x12M\nHPATIENT_PORTAL__APPOINTMENTS__FORM_APPOINTMENT_TYPES__PRE_SEARCH_RESULTS\x10\xd6\x0f\x12N\nIPATIENT_PORTAL__APPOINTMENTS__FORM_APPOINTMENT_TYPES__POST_SEARCH_RESULTS\x10\xd7\x0f\x12\x45\n@PATIENT_PORTAL__APPOINTMENTS__FORM_LOCATIONS__PRE_SEARCH_RESULTS\x10\xd8\x0f\x12\x46\nAPATIENT_PORTAL__APPOINTMENTS__FORM_LOCATIONS__POST_SEARCH_RESULTS\x10\xd9\x0f\x12\x45\n@PATIENT_PORTAL__APPOINTMENTS__FORM_PROVIDERS__PRE_SEARCH_RESULTS\x10\xda\x0f\x12\x46\nAPATIENT_PORTAL__APPOINTMENTS__FORM_PROVIDERS__POST_SEARCH_RESULTS\x10\xdb\x0f\x12.\n)PATIENT_PORTAL__APPLICATION_CONFIGURATION\x10\xdc\x0f\x12\x1a\n\x15\x41\x44\x44_APPOINTMENT_LABEL\x10\xdf\x0f\x12\x1d\n\x18REMOVE_APPOINTMENT_LABEL\x10\xe0\x0f\x12\x1a\n\x15\x41\x44\x44_BILLING_LINE_ITEM\x10\xee\x0f\x12\x1d\n\x18UPDATE_BILLING_LINE_ITEM\x10\xef\x0f\x12\x1d\n\x18REMOVE_BILLING_LINE_ITEM\x10\xf0\x0f\x12\x17\n\x12POST_CLAIM_PAYMENT\x10\xf8\x0f\x12\x16\n\x11POST_CLAIMS_REMIT\x10\xf9\x0f\x12\x18\n\x13MOVE_CLAIM_TO_QUEUE\x10\x8c\x10\x12\x14\n\x0f\x41\x44\x44_CLAIM_LABEL\x10\x82\x10\x12\x17\n\x12REMOVE_CLAIM_LABEL\x10\x83\x10\x12\x1b\n\x16UPDATE_CLAIM_LINE_ITEM\x10\xa0\x10\x12#\n\x1eSHOW_PATIENT_PORTAL_MENU_ITEMS\x10\xb4\x10\x12\x12\n\rPORTAL_WIDGET\x10\xb5\x10\x12\x11\n\x0cLAUNCH_MODAL\x10\xb8\x17\x12\x18\n\x13SIMPLE_API_RESPONSE\x10\xa0\x1f\x12 \n\x1bSIMPLE_API_WEBSOCKET_ACCEPT\x10\xa1\x1f\x12\x1e\n\x19SIMPLE_API_WEBSOCKET_DENY\x10\xa2\x1f\x12#\n\x1eSIMPLE_API_WEBSOCKET_BROADCAST\x10\xa3\x1f\x12\x10\n\x0bUPDATE_USER\x10\x88\'\x12\x10\n\x0b\x43REATE_NOTE\x10\xf0.\x12\x10\n\x0bUPDATE_NOTE\x10\xfd.\x12\x16\n\x11PUSH_NOTE_CHARGES\x10\xfc*\x12\r\n\x08\x46\x41X_NOTE\x10\x83/\x12\x0e\n\tLOCK_NOTE\x10\x89/\x12\x10\n\x0bUNLOCK_NOTE\x10\x8a/\x12\x0e\n\tSIGN_NOTE\x10\x8b/\x12\x12\n\rCHECK_IN_NOTE\x10\x8c/\x12\x11\n\x0cNO_SHOW_NOTE\x10\x8d/\x12\x17\n\x12\x43REATE_APPOINTMENT\x10\xf1.\x12\x17\n\x12UPDATE_APPOINTMENT\x10\xfe.\x12\x1b\n\x16RESCHEDULE_APPOINTMENT\x10\x86/\x12\x17\n\x12\x43\x41NCEL_APPOINTMENT\x10\xff.\x12\x1a\n\x15\x43REATE_SCHEDULE_EVENT\x10\xf2.\x12\x1a\n\x15UPDATE_SCHEDULE_EVENT\x10\x80/\x12\x1a\n\x15\x44\x45LETE_SCHEDULE_EVENT\x10\x81/\x12\x1e\n\x19RESCHEDULE_SCHEDULE_EVENT\x10\x87/\x12\x13\n\x0e\x43REATE_PATIENT\x10\xf3.\x12\x13\n\x0eUPDATE_PATIENT\x10\xf8.\x12\x13\n\x0e\x43REATE_MESSAGE\x10\xf4.\x12\x11\n\x0cSEND_MESSAGE\x10\xf5.\x12\x1c\n\x17\x43REATE_AND_SEND_MESSAGE\x10\xf6.\x12\x11\n\x0c\x45\x44IT_MESSAGE\x10\xf7.\x12/\n*PATIENT_METADATA__CREATE_ADDITIONAL_FIELDS\x10\xfa.\x12\x1c\n\x17UPSERT_PATIENT_METADATA\x10\xfb.\x12\'\n\"CREATE_PATIENT_EXTERNAL_IDENTIFIER\x10\xfc.\x12(\n#CREATE_PATIENT_PREFERRED_PHARMACIES\x10\x82/\x12\x1f\n\x1a\x43REATE_COMPOUND_MEDICATION\x10\x84/\x12\x1f\n\x1aUPDATE_COMPOUND_MEDICATION\x10\x85/\x12\x17\n\x12\x43REATE_OBSERVATION\x10\x8f/\x12\x17\n\x12UPDATE_OBSERVATION\x10\x90/\x12\x1f\n\x1aPATIENT_CHART__GROUP_ITEMS\x10\x8e/\x12\x35\n0APPOINTMENT__FORM__PROVIDERS__PRE_SEARCH_RESULTS\x10\x98/\x12\x35\n0APPOINTMENT__FORM__LOCATIONS__PRE_SEARCH_RESULTS\x10\x99/\x12\x37\n2APPOINTMENT__FORM__VISIT_TYPES__PRE_SEARCH_RESULTS\x10\x9a/\x12\x35\n0APPOINTMENT__FORM__DURATIONS__PRE_SEARCH_RESULTS\x10\x9b/\x12<\n7APPOINTMENT__FORM__REASON_FOR_VISIT__PRE_SEARCH_RESULTS\x10\x9c/\x12\x36\n1APPOINTMENT__FORM__PROVIDERS__POST_SEARCH_RESULTS\x10\x9e/\x12\x36\n1APPOINTMENT__FORM__LOCATIONS__POST_SEARCH_RESULTS\x10\x9f/\x12\x38\n3APPOINTMENT__FORM__VISIT_TYPES__POST_SEARCH_RESULTS\x10\xa0/\x12\x36\n1APPOINTMENT__FORM__DURATIONS__POST_SEARCH_RESULTS\x10\xa1/\x12=\n8APPOINTMENT__FORM__REASON_FOR_VISIT__POST_SEARCH_RESULTS\x10\xa2/\x12\x30\n+APPOINTMENT__FORM__CREATE_ADDITIONAL_FIELDS\x10\xa3/\x12 \n\x1bUPSERT_APPOINTMENT_METADATA\x10\xa4/\x12,\n\'APPOINTMENT__SLOTS__POST_SEARCH_RESULTS\x10\xa5/\x12\x18\n\x13SHOW_PANEL_SECTIONS\x10\xd4/\x12\x15\n\x10REDIRECT_CONTEXT\x10\xb8\x30\x12)\n$REVENUE__PAYMENT_PROCESSOR__METADATA\x10\xd9\x36\x12%\n REVENUE__PAYMENT_PROCESSOR__FORM\x10\xda\x36\x12\x38\n3REVENUE__PAYMENT_PROCESSOR__CREDIT_CARD_TRANSACTION\x10\xdb\x36\x12/\n*REVENUE__PAYMENT_PROCESSOR__PAYMENT_METHOD\x10\xdc\x36\x12=\n8REVENUE__PAYMENT_PROCESSOR__PAYMENT_METHOD__ADD_RESPONSE\x10\xdd\x36\x12@\n;REVENUE__PAYMENT_PROCESSOR__PAYMENT_METHOD__REMOVE_RESPONSE\x10\xde\x36\x12\x1c\n\x17GENERATE_FULL_CHART_PDF\x10\xd5/\x12\x1d\n\x18\x42\x41TCH_ORIGINATE_COMMANDS\x10\x88/\x12\x15\n\x10\x43\x41LENDAR__CREATE\x10\xc1>\x12\x1c\n\x17\x43\x41LENDAR__EVENT__CREATE\x10\xc2>\x12\x1c\n\x17\x43\x41LENDAR__EVENT__UPDATE\x10\xc3>\x12\x1c\n\x17\x43\x41LENDAR__EVENT__DELETE\x10\xc4>b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'canvas_generated.messages.effects_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_EFFECTTYPE']._serialized_start=207
  _globals['_EFFECTTYPE']._serialized_end=11296
  _globals['_EFFECT']._serialized_start=52
  _globals['_EFFECT']._serialized_end=204
# @@protoc_insertion_point(module_scope)



from typing import Literal
from uuid import UUID

from pydantic_core import InitErrorDetails

from canvas_sdk.commands.base import _BaseCommand
from canvas_sdk.commands.constants import Coding
from canvas_sdk.v1.data import ReasonForVisitSettingCoding


class ReasonForVisitCommand(_BaseCommand):
    """A class for managing a ReasonForVisit command within a specific note."""

    class Meta:
        key = "reasonForVisit"

    structured: bool = False
    coding: Coding | UUID | str | None = None
    comment: str | None = None

    def _get_error_details(
        self, method: Literal["originate", "edit", "delete", "commit", "enter_in_error"]
    ) -> list[InitErrorDetails]:
        errors = super()._get_error_details(method)
        if self.structured and not self.coding:
            errors.append(
                self._create_error_detail(
                    "value", "Structured RFV should have a coding.", self.coding
                )
            )

        if self.coding:
            if isinstance(self.coding, str | UUID):
                query = {"id": self.coding}
                error_message = f"ReasonForVisitSettingCoding with id {self.coding} does not exist."
            else:
                query = {"code": self.coding["code"], "system": self.coding["system"]}
                error_message = f"ReasonForVisitSettingCoding with code {self.coding['code']} and system {self.coding['system']} does not exist."
            if not ReasonForVisitSettingCoding.objects.filter(**query).exists():
                errors.append(self._create_error_detail("value", error_message, self.coding))
        return errors

    @classmethod
    def command_schema(cls) -> dict:
        """The schema of the command."""
        command_schema = super().command_schema()
        # the commands api does not include the 'structured' field in the fields response
        command_schema.pop("structured")
        return command_schema


__exports__ = ("ReasonForVisitCommand",)



from abc import ABC

from canvas_sdk.handlers.base import BaseHandler


class BaseProtocol(BaseHandler, ABC):
    """
    The class that protocols inherit from.
    """

    pass


__exports__ = ("BaseProtocol",)



import json
from typing import Any

from pydantic_core import InitErrorDetails, PydanticCustomError

from canvas_generated.messages.effects_pb2 import Effect
from canvas_sdk.base import TrackableFieldsModel
from canvas_sdk.v1.data.compound_medication import CompoundMedication as CompoundMedicationModel


class CompoundMedication(TrackableFieldsModel):
    """Effect to create or update a Compound Medication record."""

    class Meta:
        effect_type = "COMPOUND_MEDICATION"

    instance_id: str | None = None
    formulation: str | None = None
    potency_unit_code: str | None = None
    controlled_substance: str | None = None
    controlled_substance_ndc: str | None = None
    active: bool | None = None

    @property
    def values(self) -> dict[str, Any]:
        """Return the values of the compound medication as a dictionary, only including dirty (modified) fields."""
        return super().values

    @staticmethod
    def process_formulation(formulation: str | None) -> str | None:
        """
        Process compound medication formulation by stripping whitespace.

        Args:
            formulation: The formulation string to process

        Returns:
            Processed formulation string, or None if input was None
        """
        if formulation is None:
            return None
        return formulation.strip()

    @staticmethod
    def process_ndc(ndc: str | None) -> str | None:
        """
        Process compound medication NDC by removing dashes.

        Args:
            ndc: The NDC string to process

        Returns:
            Processed NDC string with dashes removed, or None if input was None
        """
        if ndc is None:
            return None
        return ndc.replace("-", "")

    @staticmethod
    def process_compound_medication_data(data: dict[str, Any]) -> dict[str, Any]:
        """
        Process compound medication data by applying all necessary transformations.

        Args:
            data: Dictionary containing compound medication data

        Returns:
            Processed dictionary with transformations applied
        """
        processed_data = data.copy()

        # Process formulation
        if "formulation" in processed_data and processed_data["formulation"] is not None:
            processed_data["formulation"] = CompoundMedication.process_formulation(
                processed_data["formulation"]
            )

        # Process NDC
        if (
            "controlled_substance_ndc" in processed_data
            and processed_data["controlled_substance_ndc"] is not None
        ):
            processed_data["controlled_substance_ndc"] = CompoundMedication.process_ndc(
                processed_data["controlled_substance_ndc"]
            )

        return processed_data

    @staticmethod
    def validate_compound_medication_fields(
        formulation: str | None,
        potency_unit_code: str | None,
        controlled_substance: str | None,
        controlled_substance_ndc: str | None,
    ) -> list[InitErrorDetails]:
        """
        Static method to validate compound medication fields.

        Args:
            formulation: The formulation value to validate
            potency_unit_code: The potency unit code to validate
            controlled_substance: The controlled substance to validate
            controlled_substance_ndc: The NDC to validate

        Returns:
            List of InitErrorDetails for any validation errors
        """

        def create_error(error_type: str, message: str, value: Any) -> InitErrorDetails:
            """Helper function to mimic _create_error_details."""
            return InitErrorDetails(
                {"type": PydanticCustomError(error_type, message), "input": value}
            )

        errors = []

        # Formulation validation
        if formulation is not None:
            stripped_formulation = formulation.strip()
            if not stripped_formulation:
                errors.append(
                    create_error(
                        "value",
                        "Field 'formulation' cannot be empty.",
                        formulation,
                    )
                )
            elif len(stripped_formulation) > 105:
                errors.append(
                    create_error(
                        "value",
                        "Field 'formulation' must be 105 characters or less.",
                        formulation,
                    )
                )

        # Potency unit code validation
        if potency_unit_code and potency_unit_code not in [
            choice[0] for choice in CompoundMedicationModel.PotencyUnits.choices
        ]:
            errors.append(
                create_error(
                    "value",
                    f"Invalid potency unit code: {potency_unit_code}. Must be one of: {[choice[0] for choice in CompoundMedicationModel.PotencyUnits.choices]}",
                    potency_unit_code,
                )
            )

        # Controlled substance validation
        if controlled_substance and controlled_substance not in [
            choice[0] for choice in CompoundMedicationModel.ControlledSubstanceOptions.choices
        ]:
            errors.append(
                create_error(
                    "value",
                    f"Invalid controlled substance: {controlled_substance}. Must be one of: {[choice[0] for choice in CompoundMedicationModel.ControlledSubstanceOptions.choices]}",
                    controlled_substance,
                )
            )

        # NDC validation - required when controlled substance is not "N" (Not Scheduled)
        if (
            controlled_substance
            and controlled_substance
            != CompoundMedicationModel.ControlledSubstanceOptions.SCHEDULE_NOT_SCHEDULED.value
            and (not controlled_substance_ndc or not controlled_substance_ndc.strip())
        ):
            errors.append(
                create_error(
                    "value",
                    "NDC is required when a Controlled Substance is specified.",
                    controlled_substance_ndc,
                )
            )

        return errors

    def _get_error_details(self, method: Any) -> list[InitErrorDetails]:
        errors = super()._get_error_details(method)

        if method == "create":
            if not self.formulation:
                errors.append(
                    self._create_error_detail(
                        "missing",
                        "Field 'formulation' is required to create a compound medication.",
                        None,
                    )
                )

            if not self.potency_unit_code:
                errors.append(
                    self._create_error_detail(
                        "missing",
                        "Field 'potency_unit_code' is required to create a compound medication.",
                        None,
                    )
                )

            if not self.controlled_substance:
                errors.append(
                    self._create_error_detail(
                        "missing",
                        "Field 'controlled_substance' is required to create a compound medication.",
                        None,
                    )
                )

        elif method == "update":
            if not self.instance_id:
                errors.append(
                    self._create_error_detail(
                        "missing",
                        "Field 'instance_id' is required to update a compound medication.",
                        None,
                    )
                )

        if (
            self.instance_id
            and not CompoundMedicationModel.objects.filter(id=self.instance_id).exists()
        ):
            errors.append(
                self._create_error_detail(
                    "value",
                    f"Compound medication with ID {self.instance_id} does not exist.",
                    self.instance_id,
                )
            )

        compound_med_errors = self.validate_compound_medication_fields(
            formulation=self.formulation,
            potency_unit_code=self.potency_unit_code,
            controlled_substance=self.controlled_substance,
            controlled_substance_ndc=self.controlled_substance_ndc,
        )
        errors.extend(compound_med_errors)

        return errors

    def create(self) -> Effect:
        """Create a new Compound Medication."""
        self._validate_before_effect("create")

        # Get raw values and apply explicit processing
        raw_data = self.values
        processed_data = self.process_compound_medication_data(raw_data)

        payload = {"data": processed_data}
        if self.active is None:
            payload["data"]["active"] = True

        return Effect(
            type=f"CREATE_{self.Meta.effect_type}",
            payload=json.dumps(payload),
        )

    def update(self) -> Effect:
        """Update an existing Compound Medication."""
        self._validate_before_effect("update")

        # Get raw values and apply explicit processing
        raw_data = self.values
        processed_data = self.process_compound_medication_data(raw_data)

        payload = {"data": processed_data}
        payload["data"]["instance_id"] = str(self.instance_id)

        return Effect(
            type=f"UPDATE_{self.Meta.effect_type}",
            payload=json.dumps(payload),
        )


__exports__ = ("CompoundMedication",)



from typing import Self, cast

from django.db import models
from django.db.models.manager import BaseManager
from timezone_utils.fields import TimeZoneField

from canvas_sdk.v1.data.base import BaseQuerySet, IdentifiableModel


class CalendarQuerySet(BaseQuerySet):
    """A queryset for calendars."""

    def for_calendar_name(self, provider_name: str, calendar_type: str, location: str) -> Self:
        """Return a queryset that filters objects for a specific calendar name."""
        calendar_name = f"{provider_name}: {calendar_type}{f': {location}' if location else ''}"

        return self.filter(title=calendar_name)


CalendarManager = BaseManager.from_queryset(CalendarQuerySet)


class Calendar(IdentifiableModel):
    """Model to represent the Calendar."""

    class Meta:
        db_table = "canvas_sdk_data_calendars_calendar_001"

    objects = cast(CalendarQuerySet, CalendarManager())

    title = models.CharField(max_length=128)
    timezone = TimeZoneField(default="UTC")
    description = models.TextField(blank=True, null=True)


class Event(IdentifiableModel):
    """Model to represent the Calendar Event."""

    class Meta:
        db_table = "canvas_sdk_data_calendars_event_001"

    title = models.CharField(max_length=512)
    description = models.TextField(blank=True)
    calendar = models.ForeignKey("v1.Calendar", on_delete=models.CASCADE, related_name="events")
    starts_at = models.DateTimeField()
    ends_at = models.DateTimeField()
    recurrence = models.TextField(blank=True, null=True)
    recurrence_ends_at = models.DateTimeField(blank=True, null=True)
    recurring_parent_event = models.ForeignKey(
        "self",
        on_delete=models.CASCADE,
        blank=True,
        null=True,
        related_name="exceptions",
    )
    original_starts_at = models.DateTimeField(blank=True, null=True)
    is_all_day = models.BooleanField(default=False)
    is_cancelled = models.BooleanField(default=False)
    allowed_note_types = models.ManyToManyField(
        "v1.NoteType", blank=True, db_table="canvas_sdk_data_calendars_event_allowed_note_types_001"
    )


__exports__ = ("Calendar", "Event")



from jsonschema import validators

from canvas_cli.utils.context import context
from canvas_cli.utils.print import print
from canvas_cli.utils.validators.manifest_schema import manifest_schema


def get_default_host(host: str | None) -> str | None:
    """Return context's default host if the host param is null."""
    return host or context.default_host


def validate_manifest_file(manifest_json: dict) -> None:
    """Validates a Canvas Manifest json against the manifest schema."""
    validator = validators.validator_for(manifest_schema)(manifest_schema)
    tag_warnings = []
    tag_value_warnings = []
    other_warnings = []
    for error in validator.iter_errors(manifest_json):
        if error.path and len(error.path) and error.path[0] == "tags":
            if error.validator == "enum":
                tag_value_warnings.append(error)
            elif error.validator == "additionalProperties":
                tag_warnings.append(error)
            else:
                other_warnings.append(error)
        else:
            raise error

    if tag_warnings:
        print("Warning: there are unrecognized tags in the manifest file:")
        for tag_warning in tag_warnings:
            print(f"\t- {tag_warning.message}")
    if tag_value_warnings:
        print("Warning: there are unrecognized tag values in the manifest file:")
        for tag_value_warning in tag_value_warnings:
            tag_category = tag_value_warning.path[1]
            print(
                f"\t- Please choose a valid tag value for '{tag_category}'. {tag_value_warning.message}."
            )



from __future__ import annotations

from abc import ABC, abstractmethod
from http import HTTPStatus

from canvas_sdk.clients.llms.structures.llm_response import LlmResponse
from canvas_sdk.clients.llms.structures.llm_tokens import LlmTokens
from canvas_sdk.clients.llms.structures.llm_turn import LlmTurn
from canvas_sdk.clients.llms.structures.settings.llm_settings import LlmSettings
from canvas_sdk.utils.http import Http


class LlmApi(ABC):
    """Base class for LLM (Large Language Model) API clients.

    Provides common functionality for managing conversation prompts and making requests
    to various LLM services. Subclasses should implement the request() method for
    specific LLM providers.

    Class Attributes:
        ROLE_SYSTEM: Constant for system role in conversations.
        ROLE_USER: Constant for user role in conversations.
        ROLE_MODEL: Constant for model/assistant role in conversations.
    """

    ROLE_SYSTEM = "system"
    ROLE_USER = "user"
    ROLE_MODEL = "model"

    def __init__(self, settings: LlmSettings):
        """Initialize the LLM client with settings.

        Args:
            settings: Configuration settings for the LLM API.
        """
        self.settings = settings
        self.prompts: list[LlmTurn] = []
        self.http = Http(self._api_base_url())

    def reset_prompts(self) -> None:
        """Clear all stored prompts."""
        self.prompts = []

    def add_prompt(self, prompt: LlmTurn) -> None:
        """Add a conversation turn to the prompt history.

        Routes the prompt to the appropriate method based on its role.

        Args:
            prompt: The conversation turn to add.
        """
        if prompt.role == self.ROLE_SYSTEM:
            self.set_system_prompt(prompt.text)
        elif prompt.role == self.ROLE_USER:
            self.set_user_prompt(prompt.text)
        elif prompt.role == self.ROLE_MODEL:
            self.set_model_prompt(prompt.text)

    def set_system_prompt(self, text: list[str]) -> None:
        """Set or replace the system prompt.

        The system prompt is always placed at the beginning of the conversation.
        If a system prompt already exists, it is replaced.

        Args:
            text: List of text strings for the system prompt.
        """
        prompt = LlmTurn(role=self.ROLE_SYSTEM, text=text)
        if self.prompts and self.prompts[0].role == LlmApi.ROLE_SYSTEM:
            self.prompts[0] = prompt
        else:
            self.prompts.insert(0, prompt)

    def set_user_prompt(self, text: list[str]) -> None:
        """Add a user prompt to the conversation.

        Args:
            text: List of text strings for the user prompt.
        """
        self.prompts.append(LlmTurn(role=self.ROLE_USER, text=text))

    def set_model_prompt(self, text: list[str]) -> None:
        """Add a model/assistant response to the conversation.

        Args:
            text: List of text strings for the model prompt.
        """
        self.prompts.append(LlmTurn(role=self.ROLE_MODEL, text=text))

    @abstractmethod
    def request(self) -> LlmResponse:
        """Make a request to the LLM API.

        Returns:
            Response from the LLM including status code, text, and token usage.

        Raises:
            NotImplementedError: This method must be implemented by subclasses.
        """
        ...

    @classmethod
    @abstractmethod
    def _api_base_url(cls) -> str:
        """Provide the API base url to the LlmApi subclass."""
        ...

    def attempt_requests(self, attempts: int) -> list[LlmResponse]:
        """Attempt multiple requests to the LLM API until success or max attempts.

        Args:
            attempts: Maximum number of request attempts to make.

        Returns:
            All responses from the LLM.
            If all attempts fail, returns an additional TOO_MANY_REQUESTS response.
        """
        result: list[LlmResponse] = []
        for _ in range(attempts):
            try:
                result.append(self.request())
                if result[-1].code == HTTPStatus.OK:
                    break
            except Exception as e:
                result.append(
                    LlmResponse(
                        code=HTTPStatus.INTERNAL_SERVER_ERROR,
                        response=f"Request attempt failed: {e}",
                        tokens=LlmTokens(prompt=0, generated=0),
                    )
                )
        else:
            result.append(
                LlmResponse(
                    code=HTTPStatus.TOO_MANY_REQUESTS,
                    response=f"Http error: max attempts ({attempts}) exceeded.",
                    tokens=LlmTokens(prompt=0, generated=0),
                )
            )
        return result


__exports__ = ("LlmApi",)



import logging
import os
from typing import Any

from django.conf import settings
from logstash_async.handler import AsynchronousLogstashHandler

from logger.logstash import LogstashFormatterECS
from logger.pubsub import PubSubLogHandler


class PluginLogger:
    """A custom logger for plugins."""

    def __init__(self) -> None:
        self.logger = logging.getLogger("plugin_runner_logger")
        self.logger.setLevel(logging.INFO)

        log_prefix = f"{os.getenv('HOSTNAME', '?')}: {os.getenv('APTIBLE_PROCESS_INDEX', '?')}"

        if log_prefix != "":
            log_prefix = f"[{log_prefix}] "

        formatter = logging.Formatter(
            f"plugin-runner {log_prefix}%(levelname)s %(asctime)s %(message)s"
        )

        streaming_handler = logging.StreamHandler()
        streaming_handler.setFormatter(formatter)

        self.logger.addHandler(streaming_handler)

        if settings.REDIS_ENDPOINT:
            pubsub_handler = PubSubLogHandler()
            pubsub_handler.setFormatter(formatter)

            self.logger.addHandler(pubsub_handler)

        if settings.LOGSTASH_HOST:
            logstash_handler = AsynchronousLogstashHandler(
                host=settings.LOGSTASH_HOST,
                port=settings.LOGSTASH_PORT,
                database_path=None,
                transport=settings.LOGSTASH_PROTOCOL,
            )
            logstash_handler.setFormatter(LogstashFormatterECS())
            self.logger.addHandler(logstash_handler)

    def debug(self, message: Any, *args: Any, **kwargs: Any) -> None:
        """Logs a debug message."""
        self.logger.debug(message, *args, **kwargs)

    def info(self, message: Any, *args: Any, **kwargs: Any) -> None:
        """Logs an info message."""
        self.logger.info(message, *args, **kwargs)

    def warning(self, message: Any, *args: Any, **kwargs: Any) -> None:
        """Logs a warning message."""
        self.logger.warning(message, *args, **kwargs)

    def error(self, message: Any, *args: Any, **kwargs: Any) -> None:
        """Logs an error message."""
        self.logger.error(message, *args, **kwargs)

    def exception(self, message: Any, *args: Any, **kwargs: Any) -> None:
        """Convenience method for logging an ERROR with exception information."""
        self.logger.exception(message, *args, **kwargs)

    def critical(self, message: Any, *args: Any, **kwargs: Any) -> None:
        """Logs a critical message."""
        self.logger.critical(message)


__exports__ = ()



from typing import Any
from uuid import UUID

from pydantic_core import InitErrorDetails

from canvas_sdk.effects.base import EffectType, _BaseEffect
from canvas_sdk.v1.data import ClaimLineItem


class UpdateClaimLineItem(_BaseEffect):
    """
    An Effect that updates a Claim Line Item.
    """

    class Meta:
        effect_type = EffectType.UPDATE_CLAIM_LINE_ITEM

    claim_line_item_id: str | UUID
    charge: float | None = None

    @property
    def values(self) -> dict[str, Any]:
        """The values for the payload."""
        if self.charge is None:
            return {}
        return {"charge": str(self.charge)}

    @property
    def effect_payload(self) -> dict[str, Any]:
        """The payload of the effect."""
        return {"data": self.values, "claim_line_item_id": str(self.claim_line_item_id)}

    def _get_error_details(self, method: Any) -> list[InitErrorDetails]:
        errors = super()._get_error_details(method)

        if not ClaimLineItem.objects.filter(id=self.claim_line_item_id).exists():
            errors.append(
                self._create_error_detail(
                    "value",
                    "Claim Line Item does not exist",
                    self.claim_line_item_id,
                )
            )
        return errors


__exports__ = ("UpdateClaimLineItem",)



from enum import Enum
from typing import Any

from pydantic import Field

from canvas_sdk.effects.base import EffectType, _BaseEffect


class PatientPortalMenuConfiguration(_BaseEffect):
    """
    An Effect that will decide which menu items appear on the patient portal menu.
    """

    class Meta:
        effect_type = EffectType.SHOW_PATIENT_PORTAL_MENU_ITEMS

    class MenuItems(Enum):
        APPOINTMENTS = "appointments"
        MESSAGING = "messaging"
        MY_HEALTH = "my_health"
        PAYMENTS = "payments"
        LABS = "labs"
        CONTACT = "contact"
        RECORDS = "records"

    items: list[MenuItems] = Field(min_length=1)

    @property
    def values(self) -> dict[str, Any]:
        """The PatientPortalMenuConfiguration's values."""
        return {"items": [i.value for i in self.items]}

    @property
    def effect_payload(self) -> dict[str, Any]:
        """The payload of the effect."""
        return {"data": self.values}


__exports__ = ("PatientPortalMenuConfiguration",)
